## 3.0.10.5 (2023-05-10)

Add `partial_stub` metadata field (#10157)

## 3.0.10.4 (2023-03-27)

Add defaults for third-party stubs E-H (#9954)

## 3.0.10.3 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 3.0.10.2 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9558)

## 3.0.10.1 (2023-01-13)

`Flask-Cors`: Add `Flask` as a dependency (#9516)

## 3.0.10 (2022-07-12)

Import `Match` and `Pattern` from `re`, not `typing` (#8277)

## 3.0.9 (2022-07-07)

Fix various `TypeAlias` issues (#8248)

## 3.0.8 (2022-05-07)

Import generics from standard modules in all third-party stubs (#7791)

## 3.0.7 (2022-05-06)

`flask-cors.decorator`: allow `re.Pattern` objects to `origins` and `allow_headers` parameters (#7782)

## 3.0.6 (2022-04-20)

Use `TypeAlias` for type aliases where possible, part II (#7667)

## 3.0.5 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 3.0.4 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 3.0.3 (2022-03-19)

Add mypy error codes to `type: ignore`s, remove unused ignores (#7504)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 3.0.2 (2022-02-20)

flask-cors: remove unused allowlist (#7309)

Co-authored-by: hauntsaninja <>

## 3.0.1 (2022-01-22)

Use class-based syntax for `TypedDict` in `Flask-Cors/flask_cors/core.pyi` (#6995)

Refs https://github.com/PyCQA/flake8-pyi/pull/133

Add missing default values to flask-cors cross_origin (#6994)

## 3.0.0 (2022-01-22)

Add stubs for flask-cors (#6939)

